# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.enumeration
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.foundation.numerics
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.media
import winsdk.windows.media.audio
import winsdk.windows.media.casting
import winsdk.windows.media.core
import winsdk.windows.media.mediaproperties
import winsdk.windows.media.protection
import winsdk.windows.storage
import winsdk.windows.storage.streams
import winsdk.windows.ui.composition

class AutoLoadedDisplayPropertyKind(enum.IntEnum):
    NONE = 0
    MUSIC_OR_VIDEO = 1
    MUSIC = 2
    VIDEO = 3

class FailedMediaStreamKind(enum.IntEnum):
    UNKNOWN = 0
    AUDIO = 1
    VIDEO = 2

class MediaBreakInsertionMethod(enum.IntEnum):
    INTERRUPT = 0
    REPLACE = 1

class MediaCommandEnablingRule(enum.IntEnum):
    AUTO = 0
    ALWAYS = 1
    NEVER = 2

class MediaPlaybackItemChangedReason(enum.IntEnum):
    INITIAL_ITEM = 0
    END_OF_STREAM = 1
    ERROR = 2
    APP_REQUESTED = 3

class MediaPlaybackItemErrorCode(enum.IntEnum):
    NONE = 0
    ABORTED = 1
    NETWORK_ERROR = 2
    DECODE_ERROR = 3
    SOURCE_NOT_SUPPORTED_ERROR = 4
    ENCRYPTION_ERROR = 5

class MediaPlaybackSessionVideoConstrictionReason(enum.IntEnum):
    NONE = 0
    VIRTUAL_MACHINE = 1
    UNSUPPORTED_DISPLAY_ADAPTER = 2
    UNSIGNED_DRIVER = 3
    FRAME_SERVER_ENABLED = 4
    OUTPUT_PROTECTION_FAILED = 5
    UNKNOWN = 6

class MediaPlaybackState(enum.IntEnum):
    NONE = 0
    OPENING = 1
    BUFFERING = 2
    PLAYING = 3
    PAUSED = 4

class MediaPlayerAudioCategory(enum.IntEnum):
    OTHER = 0
    COMMUNICATIONS = 3
    ALERTS = 4
    SOUND_EFFECTS = 5
    GAME_EFFECTS = 6
    GAME_MEDIA = 7
    GAME_CHAT = 8
    SPEECH = 9
    MOVIE = 10
    MEDIA = 11

class MediaPlayerAudioDeviceType(enum.IntEnum):
    CONSOLE = 0
    MULTIMEDIA = 1
    COMMUNICATIONS = 2

class MediaPlayerError(enum.IntEnum):
    UNKNOWN = 0
    ABORTED = 1
    NETWORK_ERROR = 2
    DECODING_ERROR = 3
    SOURCE_NOT_SUPPORTED = 4

class MediaPlayerState(enum.IntEnum):
    CLOSED = 0
    OPENING = 1
    BUFFERING = 2
    PLAYING = 3
    PAUSED = 4
    STOPPED = 5

class SphericalVideoProjectionMode(enum.IntEnum):
    SPHERICAL = 0
    FLAT = 1

class StereoscopicVideoRenderMode(enum.IntEnum):
    MONO = 0
    STEREO = 1

class TimedMetadataTrackPresentationMode(enum.IntEnum):
    DISABLED = 0
    HIDDEN = 1
    APPLICATION_PRESENTED = 2
    PLATFORM_PRESENTED = 3

Self = typing.TypeVar('Self')

class BackgroundMediaPlayer(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[MediaPlayer]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BackgroundMediaPlayer: ...
    @staticmethod
    def is_media_playing() -> winsdk.system.Boolean: ...
    @staticmethod
    def send_message_to_background(value: typing.Optional[winsdk.windows.foundation.collections.ValueSet]) -> None: ...
    @staticmethod
    def send_message_to_foreground(value: typing.Optional[winsdk.windows.foundation.collections.ValueSet]) -> None: ...
    @staticmethod
    def shutdown() -> None: ...
    @staticmethod
    def add_message_received_from_background(value: winsdk.windows.foundation.EventHandler[MediaPlayerDataReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_message_received_from_background(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_message_received_from_foreground(value: winsdk.windows.foundation.EventHandler[MediaPlayerDataReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_message_received_from_foreground(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CurrentMediaPlaybackItemChangedEventArgs(winsdk.system.Object):
    new_item: typing.Optional[MediaPlaybackItem]
    old_item: typing.Optional[MediaPlaybackItem]
    reason: MediaPlaybackItemChangedReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CurrentMediaPlaybackItemChangedEventArgs: ...

class MediaBreak(winsdk.system.Object):
    can_start: winsdk.system.Boolean
    custom_properties: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    insertion_method: MediaBreakInsertionMethod
    playback_list: typing.Optional[MediaPlaybackList]
    presentation_position: typing.Optional[typing.Optional[datetime.timedelta]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaBreak: ...
    @typing.overload
    def __new__(cls: typing.Type[MediaBreak], insertion_method: MediaBreakInsertionMethod) -> MediaBreak:...
    @typing.overload
    def __new__(cls: typing.Type[MediaBreak], insertion_method: MediaBreakInsertionMethod, presentation_position: datetime.timedelta) -> MediaBreak:...

class MediaBreakEndedEventArgs(winsdk.system.Object):
    media_break: typing.Optional[MediaBreak]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaBreakEndedEventArgs: ...

class MediaBreakManager(winsdk.system.Object):
    current_break: typing.Optional[MediaBreak]
    playback_session: typing.Optional[MediaPlaybackSession]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaBreakManager: ...
    def play_break(self, value: typing.Optional[MediaBreak]) -> None: ...
    def skip_current_break(self) -> None: ...
    def add_break_ended(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaBreakManager, MediaBreakEndedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_break_ended(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_break_skipped(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaBreakManager, MediaBreakSkippedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_break_skipped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_break_started(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaBreakManager, MediaBreakStartedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_break_started(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_breaks_seeked_over(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaBreakManager, MediaBreakSeekedOverEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_breaks_seeked_over(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaBreakSchedule(winsdk.system.Object):
    preroll_break: typing.Optional[MediaBreak]
    postroll_break: typing.Optional[MediaBreak]
    midroll_breaks: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaBreak]]
    playback_item: typing.Optional[MediaPlaybackItem]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaBreakSchedule: ...
    def insert_midroll_break(self, media_break: typing.Optional[MediaBreak]) -> None: ...
    def remove_midroll_break(self, media_break: typing.Optional[MediaBreak]) -> None: ...
    def add_schedule_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaBreakSchedule, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_schedule_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaBreakSeekedOverEventArgs(winsdk.system.Object):
    new_position: datetime.timedelta
    old_position: datetime.timedelta
    seeked_over_breaks: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaBreak]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaBreakSeekedOverEventArgs: ...

class MediaBreakSkippedEventArgs(winsdk.system.Object):
    media_break: typing.Optional[MediaBreak]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaBreakSkippedEventArgs: ...

class MediaBreakStartedEventArgs(winsdk.system.Object):
    media_break: typing.Optional[MediaBreak]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaBreakStartedEventArgs: ...

class MediaItemDisplayProperties(winsdk.system.Object):
    type: winsdk.windows.media.MediaPlaybackType
    thumbnail: typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference]
    music_properties: typing.Optional[winsdk.windows.media.MusicDisplayProperties]
    video_properties: typing.Optional[winsdk.windows.media.VideoDisplayProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaItemDisplayProperties: ...
    def clear_all(self) -> None: ...

class MediaPlaybackAudioTrackList(winsdk.system.Object, typing.Sequence[winsdk.windows.media.core.AudioTrack]):
    size: winsdk.system.UInt32
    selected_index: winsdk.system.Int32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> winsdk.windows.media.core.AudioTrack: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[winsdk.windows.media.core.AudioTrack]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackAudioTrackList: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.media.core.AudioTrack]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.media.core.AudioTrack]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[winsdk.windows.media.core.AudioTrack]) -> winsdk.system.UInt32: ...
    def index_of(self, value: typing.Optional[winsdk.windows.media.core.AudioTrack]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def add_selected_index_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.media.core.ISingleSelectMediaTrackList, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_selected_index_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlaybackCommandManager(winsdk.system.Object):
    is_enabled: winsdk.system.Boolean
    auto_repeat_mode_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    fast_forward_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    media_player: typing.Optional[MediaPlayer]
    next_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    pause_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    play_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    position_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    previous_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    rate_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    rewind_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    shuffle_behavior: typing.Optional[MediaPlaybackCommandManagerCommandBehavior]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManager: ...
    def add_auto_repeat_mode_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerAutoRepeatModeReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_auto_repeat_mode_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_fast_forward_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerFastForwardReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_fast_forward_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_next_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerNextReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_next_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_pause_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerPauseReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_pause_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_play_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerPlayReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_play_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_position_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerPositionReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_position_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_previous_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerPreviousReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_previous_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_rate_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerRateReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_rate_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_rewind_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerRewindReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_rewind_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_shuffle_received(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManager, MediaPlaybackCommandManagerShuffleReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_shuffle_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlaybackCommandManagerAutoRepeatModeReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    auto_repeat_mode: winsdk.windows.media.MediaPlaybackAutoRepeatMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerAutoRepeatModeReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerCommandBehavior(winsdk.system.Object):
    enabling_rule: MediaCommandEnablingRule
    command_manager: typing.Optional[MediaPlaybackCommandManager]
    is_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerCommandBehavior: ...
    def add_is_enabled_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackCommandManagerCommandBehavior, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlaybackCommandManagerFastForwardReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerFastForwardReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerNextReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerNextReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerPauseReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerPauseReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerPlayReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerPlayReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerPositionReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    position: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerPositionReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerPreviousReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerPreviousReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerRateReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    playback_rate: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerRateReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerRewindReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerRewindReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackCommandManagerShuffleReceivedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    is_shuffle_requested: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackCommandManagerShuffleReceivedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class MediaPlaybackItem(winsdk.system.Object):
    audio_tracks: typing.Optional[MediaPlaybackAudioTrackList]
    source: typing.Optional[winsdk.windows.media.core.MediaSource]
    timed_metadata_tracks: typing.Optional[MediaPlaybackTimedMetadataTrackList]
    video_tracks: typing.Optional[MediaPlaybackVideoTrackList]
    can_skip: winsdk.system.Boolean
    break_schedule: typing.Optional[MediaBreakSchedule]
    duration_limit: typing.Optional[typing.Optional[datetime.timedelta]]
    start_time: datetime.timedelta
    is_disabled_in_playback_list: winsdk.system.Boolean
    auto_loaded_display_properties: AutoLoadedDisplayPropertyKind
    total_download_progress: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackItem: ...
    @typing.overload
    def __new__(cls: typing.Type[MediaPlaybackItem], source: typing.Optional[winsdk.windows.media.core.MediaSource], start_time: datetime.timedelta) -> MediaPlaybackItem:...
    @typing.overload
    def __new__(cls: typing.Type[MediaPlaybackItem], source: typing.Optional[winsdk.windows.media.core.MediaSource], start_time: datetime.timedelta, duration_limit: datetime.timedelta) -> MediaPlaybackItem:...
    @typing.overload
    def __new__(cls: typing.Type[MediaPlaybackItem], source: typing.Optional[winsdk.windows.media.core.MediaSource]) -> MediaPlaybackItem:...
    def apply_display_properties(self, value: typing.Optional[MediaItemDisplayProperties]) -> None: ...
    @staticmethod
    def find_from_media_source(source: typing.Optional[winsdk.windows.media.core.MediaSource]) -> typing.Optional[MediaPlaybackItem]: ...
    def get_display_properties(self) -> typing.Optional[MediaItemDisplayProperties]: ...
    def add_audio_tracks_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackItem, winsdk.windows.foundation.collections.IVectorChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_audio_tracks_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_timed_metadata_tracks_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackItem, winsdk.windows.foundation.collections.IVectorChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_timed_metadata_tracks_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_tracks_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackItem, winsdk.windows.foundation.collections.IVectorChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_tracks_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlaybackItemError(winsdk.system.Object):
    error_code: MediaPlaybackItemErrorCode
    extended_error: winsdk.windows.foundation.HResult
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackItemError: ...

class MediaPlaybackItemFailedEventArgs(winsdk.system.Object):
    error: typing.Optional[MediaPlaybackItemError]
    item: typing.Optional[MediaPlaybackItem]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackItemFailedEventArgs: ...

class MediaPlaybackItemOpenedEventArgs(winsdk.system.Object):
    item: typing.Optional[MediaPlaybackItem]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackItemOpenedEventArgs: ...

class MediaPlaybackList(winsdk.system.Object):
    shuffle_enabled: winsdk.system.Boolean
    auto_repeat_enabled: winsdk.system.Boolean
    current_item: typing.Optional[MediaPlaybackItem]
    current_item_index: winsdk.system.UInt32
    items: typing.Optional[winsdk.windows.foundation.collections.IObservableVector[MediaPlaybackItem]]
    starting_item: typing.Optional[MediaPlaybackItem]
    max_prefetch_time: typing.Optional[typing.Optional[datetime.timedelta]]
    shuffled_items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MediaPlaybackItem]]
    max_played_items_to_keep_open: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackList: ...
    def __new__(cls: typing.Type[MediaPlaybackList]) -> MediaPlaybackList:...
    def move_next(self) -> typing.Optional[MediaPlaybackItem]: ...
    def move_previous(self) -> typing.Optional[MediaPlaybackItem]: ...
    def move_to(self, item_index: winsdk.system.UInt32) -> typing.Optional[MediaPlaybackItem]: ...
    def set_shuffled_items(self, value: typing.Iterable[MediaPlaybackItem]) -> None: ...
    def add_current_item_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackList, CurrentMediaPlaybackItemChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_current_item_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_item_failed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackList, MediaPlaybackItemFailedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_item_failed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_item_opened(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackList, MediaPlaybackItemOpenedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_item_opened(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlaybackSession(winsdk.system.Object):
    stereoscopic_video_packing_mode: winsdk.windows.media.mediaproperties.StereoscopicVideoPackingMode
    position: datetime.timedelta
    playback_rate: winsdk.system.Double
    normalized_source_rect: winsdk.windows.foundation.Rect
    buffering_progress: winsdk.system.Double
    can_pause: winsdk.system.Boolean
    can_seek: winsdk.system.Boolean
    download_progress: winsdk.system.Double
    is_protected: winsdk.system.Boolean
    media_player: typing.Optional[MediaPlayer]
    natural_duration: datetime.timedelta
    natural_video_height: winsdk.system.UInt32
    natural_video_width: winsdk.system.UInt32
    playback_state: MediaPlaybackState
    is_mirroring: winsdk.system.Boolean
    spherical_video_projection: typing.Optional[MediaPlaybackSphericalVideoProjection]
    playback_rotation: winsdk.windows.media.mediaproperties.MediaRotation
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackSession: ...
    def get_buffered_ranges(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.MediaTimeRange]]: ...
    def get_output_degradation_policy_state(self) -> typing.Optional[MediaPlaybackSessionOutputDegradationPolicyState]: ...
    def get_played_ranges(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.MediaTimeRange]]: ...
    def get_seekable_ranges(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.MediaTimeRange]]: ...
    def is_supported_playback_rate_range(self, rate1: winsdk.system.Double, rate2: winsdk.system.Double) -> winsdk.system.Boolean: ...
    def add_buffering_ended(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_buffering_ended(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_buffering_progress_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_buffering_progress_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_buffering_started(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_buffering_started(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_download_progress_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_download_progress_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_natural_duration_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_natural_duration_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_natural_video_size_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_natural_video_size_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_playback_rate_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_playback_rate_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_playback_state_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_playback_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_position_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_position_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_seek_completed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_seek_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_buffered_ranges_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_buffered_ranges_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_played_ranges_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_played_ranges_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_seekable_ranges_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_seekable_ranges_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_supported_playback_rates_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackSession, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_supported_playback_rates_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlaybackSessionBufferingStartedEventArgs(winsdk.system.Object):
    is_playback_interruption: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackSessionBufferingStartedEventArgs: ...

class MediaPlaybackSessionOutputDegradationPolicyState(winsdk.system.Object):
    video_constriction_reason: MediaPlaybackSessionVideoConstrictionReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackSessionOutputDegradationPolicyState: ...

class MediaPlaybackSphericalVideoProjection(winsdk.system.Object):
    view_orientation: winsdk.windows.foundation.numerics.Quaternion
    projection_mode: SphericalVideoProjectionMode
    is_enabled: winsdk.system.Boolean
    horizontal_field_of_view_in_degrees: winsdk.system.Double
    frame_format: winsdk.windows.media.mediaproperties.SphericalVideoFrameFormat
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackSphericalVideoProjection: ...

class MediaPlaybackTimedMetadataTrackList(winsdk.system.Object, typing.Sequence[winsdk.windows.media.core.TimedMetadataTrack]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> winsdk.windows.media.core.TimedMetadataTrack: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[winsdk.windows.media.core.TimedMetadataTrack]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackTimedMetadataTrackList: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.media.core.TimedMetadataTrack]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.media.core.TimedMetadataTrack]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[winsdk.windows.media.core.TimedMetadataTrack]) -> winsdk.system.UInt32: ...
    def get_presentation_mode(self, index: winsdk.system.UInt32) -> TimedMetadataTrackPresentationMode: ...
    def index_of(self, value: typing.Optional[winsdk.windows.media.core.TimedMetadataTrack]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def set_presentation_mode(self, index: winsdk.system.UInt32, value: TimedMetadataTrackPresentationMode) -> None: ...
    def add_presentation_mode_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlaybackTimedMetadataTrackList, TimedMetadataPresentationModeChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_presentation_mode_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlaybackVideoTrackList(winsdk.system.Object, typing.Sequence[winsdk.windows.media.core.VideoTrack]):
    size: winsdk.system.UInt32
    selected_index: winsdk.system.Int32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> winsdk.windows.media.core.VideoTrack: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[winsdk.windows.media.core.VideoTrack]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlaybackVideoTrackList: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.media.core.VideoTrack]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.media.core.VideoTrack]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[winsdk.windows.media.core.VideoTrack]) -> winsdk.system.UInt32: ...
    def index_of(self, value: typing.Optional[winsdk.windows.media.core.VideoTrack]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def add_selected_index_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.media.core.ISingleSelectMediaTrackList, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_selected_index_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlayer(winsdk.system.Object):
    volume: winsdk.system.Double
    position: datetime.timedelta
    playback_rate: winsdk.system.Double
    is_looping_enabled: winsdk.system.Boolean
    is_muted: winsdk.system.Boolean
    auto_play: winsdk.system.Boolean
    current_state: MediaPlayerState
    natural_duration: datetime.timedelta
    playback_media_markers: typing.Optional[PlaybackMediaMarkerSequence]
    is_protected: winsdk.system.Boolean
    buffering_progress: winsdk.system.Double
    can_pause: winsdk.system.Boolean
    can_seek: winsdk.system.Boolean
    audio_device_type: MediaPlayerAudioDeviceType
    audio_category: MediaPlayerAudioCategory
    system_media_transport_controls: typing.Optional[winsdk.windows.media.SystemMediaTransportControls]
    timeline_controller_position_offset: datetime.timedelta
    timeline_controller: typing.Optional[winsdk.windows.media.MediaTimelineController]
    stereoscopic_video_render_mode: StereoscopicVideoRenderMode
    real_time_playback: winsdk.system.Boolean
    audio_device: typing.Optional[winsdk.windows.devices.enumeration.DeviceInformation]
    audio_balance: winsdk.system.Double
    command_manager: typing.Optional[MediaPlaybackCommandManager]
    break_manager: typing.Optional[MediaBreakManager]
    playback_session: typing.Optional[MediaPlaybackSession]
    is_video_frame_server_enabled: winsdk.system.Boolean
    audio_state_monitor: typing.Optional[winsdk.windows.media.audio.AudioStateMonitor]
    protection_manager: typing.Optional[winsdk.windows.media.protection.MediaProtectionManager]
    source: typing.Optional[IMediaPlaybackSource]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlayer: ...
    def __new__(cls: typing.Type[MediaPlayer]) -> MediaPlayer:...
    def add_audio_effect(self, activatable_class_id: str, effect_optional: winsdk.system.Boolean, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    def add_video_effect(self, activatable_class_id: str, effect_optional: winsdk.system.Boolean, effect_configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    def close(self) -> None: ...
    def copy_frame_to_stereoscopic_video_surfaces(self, destination_left_eye: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface], destination_right_eye: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]) -> None: ...
    @typing.overload
    def copy_frame_to_video_surface(self, destination: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]) -> None: ...
    @typing.overload
    def copy_frame_to_video_surface(self, destination: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface], target_rectangle: winsdk.windows.foundation.Rect) -> None: ...
    def get_as_casting_source(self) -> typing.Optional[winsdk.windows.media.casting.CastingSource]: ...
    def get_surface(self, compositor: typing.Optional[winsdk.windows.ui.composition.Compositor]) -> typing.Optional[MediaPlayerSurface]: ...
    def pause(self) -> None: ...
    def play(self) -> None: ...
    def remove_all_effects(self) -> None: ...
    @typing.overload
    def render_subtitles_to_surface(self, destination: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]) -> winsdk.system.Boolean: ...
    @typing.overload
    def render_subtitles_to_surface(self, destination: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface], target_rectangle: winsdk.windows.foundation.Rect) -> winsdk.system.Boolean: ...
    def set_file_source(self, file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> None: ...
    def set_media_source(self, source: typing.Optional[winsdk.windows.media.core.IMediaSource]) -> None: ...
    def set_stream_source(self, stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> None: ...
    def set_surface_size(self, size: winsdk.windows.foundation.Size) -> None: ...
    def set_uri_source(self, value: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    def step_backward_one_frame(self) -> None: ...
    def step_forward_one_frame(self) -> None: ...
    def add_buffering_ended(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_buffering_ended(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_buffering_started(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_buffering_started(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_current_state_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_current_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_media_ended(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_media_ended(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_media_failed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, MediaPlayerFailedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_media_failed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_media_opened(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_media_opened(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_media_player_rate_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, MediaPlayerRateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_media_player_rate_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_playback_media_marker_reached(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, PlaybackMediaMarkerReachedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_playback_media_marker_reached(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_seek_completed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_seek_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_volume_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_volume_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_is_muted_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_is_muted_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_source_changed(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_source_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_video_frame_available(self, value: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_video_frame_available(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_subtitle_frame_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[MediaPlayer, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_subtitle_frame_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaPlayerDataReceivedEventArgs(winsdk.system.Object):
    data: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlayerDataReceivedEventArgs: ...

class MediaPlayerFailedEventArgs(winsdk.system.Object):
    error: MediaPlayerError
    error_message: str
    extended_error_code: winsdk.windows.foundation.HResult
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlayerFailedEventArgs: ...

class MediaPlayerRateChangedEventArgs(winsdk.system.Object):
    new_rate: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlayerRateChangedEventArgs: ...

class MediaPlayerSurface(winsdk.system.Object):
    composition_surface: typing.Optional[winsdk.windows.ui.composition.ICompositionSurface]
    compositor: typing.Optional[winsdk.windows.ui.composition.Compositor]
    media_player: typing.Optional[MediaPlayer]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPlayerSurface: ...
    def close(self) -> None: ...

class PlaybackMediaMarker(winsdk.system.Object):
    media_marker_type: str
    text: str
    time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaybackMediaMarker: ...
    @typing.overload
    def __new__(cls: typing.Type[PlaybackMediaMarker], value: datetime.timedelta) -> PlaybackMediaMarker:...
    @typing.overload
    def __new__(cls: typing.Type[PlaybackMediaMarker], value: datetime.timedelta, media_market_type: str, text: str) -> PlaybackMediaMarker:...

class PlaybackMediaMarkerReachedEventArgs(winsdk.system.Object):
    playback_media_marker: typing.Optional[PlaybackMediaMarker]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaybackMediaMarkerReachedEventArgs: ...

class PlaybackMediaMarkerSequence(winsdk.system.Object):
    size: winsdk.system.UInt32
    def __iter__(self) -> winsdk.windows.foundation.collections.IIterator[PlaybackMediaMarker]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaybackMediaMarkerSequence: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[PlaybackMediaMarker]]: ...
    def insert(self, value: typing.Optional[PlaybackMediaMarker]) -> None: ...

class TimedMetadataPresentationModeChangedEventArgs(winsdk.system.Object):
    new_presentation_mode: TimedMetadataTrackPresentationMode
    old_presentation_mode: TimedMetadataTrackPresentationMode
    track: typing.Optional[winsdk.windows.media.core.TimedMetadataTrack]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TimedMetadataPresentationModeChangedEventArgs: ...

class IMediaEnginePlaybackSource(winsdk.system.Object):
    current_item: typing.Optional[MediaPlaybackItem]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaEnginePlaybackSource: ...
    def set_playback_source(self, source: typing.Optional[IMediaPlaybackSource]) -> None: ...

class IMediaPlaybackSource(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaPlaybackSource: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.appointments
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.cryptography.certificates
import winsdk.windows.storage.streams
import winsdk.windows.system

class EmailAttachmentDownloadState(enum.IntEnum):
    NOT_DOWNLOADED = 0
    DOWNLOADING = 1
    DOWNLOADED = 2
    FAILED = 3

class EmailBatchStatus(enum.IntEnum):
    SUCCESS = 0
    SERVER_SEARCH_SYNC_MANAGER_ERROR = 1
    SERVER_SEARCH_UNKNOWN_ERROR = 2

class EmailCertificateValidationStatus(enum.IntEnum):
    SUCCESS = 0
    NO_MATCH = 1
    INVALID_USAGE = 2
    INVALID_CERTIFICATE = 3
    REVOKED = 4
    CHAIN_REVOKED = 5
    REVOCATION_SERVER_FAILURE = 6
    EXPIRED = 7
    UNTRUSTED = 8
    SERVER_ERROR = 9
    UNKNOWN_FAILURE = 10

class EmailFlagState(enum.IntEnum):
    UNFLAGGED = 0
    FLAGGED = 1
    COMPLETED = 2
    CLEARED = 3

class EmailImportance(enum.IntEnum):
    NORMAL = 0
    HIGH = 1
    LOW = 2

class EmailMailboxActionKind(enum.IntEnum):
    MARK_MESSAGE_AS_SEEN = 0
    MARK_MESSAGE_READ = 1
    CHANGE_MESSAGE_FLAG_STATE = 2
    MOVE_MESSAGE = 3
    SAVE_DRAFT = 4
    SEND_MESSAGE = 5
    CREATE_RESPONSE_REPLY_MESSAGE = 6
    CREATE_RESPONSE_REPLY_ALL_MESSAGE = 7
    CREATE_RESPONSE_FORWARD_MESSAGE = 8
    MOVE_FOLDER = 9
    MARK_FOLDER_FOR_SYNC_ENABLED = 10

class EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation(enum.IntEnum):
    NONE = 0
    STRONG_ALGORITHM = 1
    ANY_ALGORITHM = 2

class EmailMailboxAutoReplyMessageResponseKind(enum.IntEnum):
    HTML = 0
    PLAIN_TEXT = 1

class EmailMailboxChangeType(enum.IntEnum):
    MESSAGE_CREATED = 0
    MESSAGE_MODIFIED = 1
    MESSAGE_DELETED = 2
    FOLDER_CREATED = 3
    FOLDER_MODIFIED = 4
    FOLDER_DELETED = 5
    CHANGE_TRACKING_LOST = 6

class EmailMailboxCreateFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    NAME_COLLISION = 5
    SERVER_REJECTED = 6

class EmailMailboxDeleteFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    COULD_NOT_DELETE_EVERYTHING = 5

class EmailMailboxEmptyFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    COULD_NOT_DELETE_EVERYTHING = 5

class EmailMailboxOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    FULL = 1
    NONE = 2

class EmailMailboxOtherAppWriteAccess(enum.IntEnum):
    NONE = 0
    LIMITED = 1

class EmailMailboxSmimeEncryptionAlgorithm(enum.IntEnum):
    ANY = 0
    TRIPLE_DES = 1
    DES = 2
    R_C2128_BIT = 3
    R_C264_BIT = 4
    R_C240_BIT = 5

class EmailMailboxSmimeSigningAlgorithm(enum.IntEnum):
    ANY = 0
    SHA1 = 1
    M_D5 = 2

class EmailMailboxSyncStatus(enum.IntEnum):
    IDLE = 0
    SYNCING = 1
    UP_TO_DATE = 2
    AUTHENTICATION_ERROR = 3
    POLICY_ERROR = 4
    UNKNOWN_ERROR = 5
    MANUAL_ACCOUNT_REMOVAL_REQUIRED = 6

class EmailMeetingResponseType(enum.IntEnum):
    ACCEPT = 0
    DECLINE = 1
    TENTATIVE = 2

class EmailMessageBodyKind(enum.IntEnum):
    HTML = 0
    PLAIN_TEXT = 1

class EmailMessageDownloadState(enum.IntEnum):
    PARTIALLY_DOWNLOADED = 0
    DOWNLOADING = 1
    DOWNLOADED = 2
    FAILED = 3

class EmailMessageResponseKind(enum.IntEnum):
    NONE = 0
    REPLY = 1
    REPLY_ALL = 2
    FORWARD = 3

class EmailMessageSmimeKind(enum.IntEnum):
    NONE = 0
    CLEAR_SIGNED = 1
    OPAQUE_SIGNED = 2
    ENCRYPTED = 3

class EmailQueryKind(enum.IntEnum):
    ALL = 0
    IMPORTANT = 1
    FLAGGED = 2
    UNREAD = 3
    READ = 4
    UNSEEN = 5

class EmailQuerySearchFields(enum.IntFlag):
    NONE = 0
    SUBJECT = 0x1
    SENDER = 0x2
    PREVIEW = 0x4
    RECIPIENTS = 0x8
    ALL = 0xffffffff

class EmailQuerySearchScope(enum.IntEnum):
    LOCAL = 0
    SERVER = 1

class EmailQuerySortDirection(enum.IntEnum):
    DESCENDING = 0
    ASCENDING = 1

class EmailQuerySortProperty(enum.IntEnum):
    DATE = 0

class EmailRecipientResolutionStatus(enum.IntEnum):
    SUCCESS = 0
    RECIPIENT_NOT_FOUND = 1
    AMBIGUOUS_RECIPIENT = 2
    NO_CERTIFICATE = 3
    CERTIFICATE_REQUEST_LIMIT_REACHED = 4
    CANNOT_RESOLVE_DISTRIBUTION_LIST = 5
    SERVER_ERROR = 6
    UNKNOWN_FAILURE = 7

class EmailSpecialFolderKind(enum.IntEnum):
    NONE = 0
    ROOT = 1
    INBOX = 2
    OUTBOX = 3
    DRAFTS = 4
    DELETED_ITEMS = 5
    SENT = 6

class EmailStoreAccessType(enum.IntEnum):
    APP_MAILBOXES_READ_WRITE = 0
    ALL_MAILBOXES_LIMITED_READ_WRITE = 1

Self = typing.TypeVar('Self')

class EmailAttachment(winsdk.system.Object):
    file_name: str
    data: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    mime_type: str
    is_inline: winsdk.system.Boolean
    estimated_download_size_in_bytes: winsdk.system.UInt64
    download_state: EmailAttachmentDownloadState
    content_location: str
    content_id: str
    id: str
    is_from_base_message: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailAttachment: ...
    @typing.overload
    def __new__(cls: typing.Type[EmailAttachment], file_name: str, data: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference], mime_type: str) -> EmailAttachment:...
    @typing.overload
    def __new__(cls: typing.Type[EmailAttachment], file_name: str, data: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> EmailAttachment:...
    @typing.overload
    def __new__(cls: typing.Type[EmailAttachment]) -> EmailAttachment:...

class EmailConversation(winsdk.system.Object):
    flag_state: EmailFlagState
    has_attachment: winsdk.system.Boolean
    id: str
    importance: EmailImportance
    last_email_response_kind: EmailMessageResponseKind
    latest_sender: typing.Optional[EmailRecipient]
    mailbox_id: str
    message_count: winsdk.system.UInt32
    most_recent_message_id: str
    most_recent_message_time: datetime.datetime
    preview: str
    subject: str
    unread_message_count: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailConversation: ...
    @typing.overload
    def find_messages_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EmailMessage]]: ...
    @typing.overload
    def find_messages_async(self, count: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EmailMessage]]: ...

class EmailConversationBatch(winsdk.system.Object):
    conversations: typing.Optional[winsdk.windows.foundation.collections.IVectorView[EmailConversation]]
    status: EmailBatchStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailConversationBatch: ...

class EmailConversationReader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailConversationReader: ...
    def read_batch_async(self) -> winsdk.windows.foundation.IAsyncOperation[EmailConversationBatch]: ...

class EmailFolder(winsdk.system.Object):
    remote_id: str
    last_successful_sync_time: datetime.datetime
    is_sync_enabled: winsdk.system.Boolean
    display_name: str
    id: str
    kind: EmailSpecialFolderKind
    mailbox_id: str
    parent_folder_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailFolder: ...
    def create_folder_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[EmailFolder]: ...
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def find_child_folders_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EmailFolder]]: ...
    @typing.overload
    def get_conversation_reader(self) -> typing.Optional[EmailConversationReader]: ...
    @typing.overload
    def get_conversation_reader(self, options: typing.Optional[EmailQueryOptions]) -> typing.Optional[EmailConversationReader]: ...
    def get_message_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMessage]: ...
    def get_message_counts_async(self) -> winsdk.windows.foundation.IAsyncOperation[EmailItemCounts]: ...
    @typing.overload
    def get_message_reader(self) -> typing.Optional[EmailMessageReader]: ...
    @typing.overload
    def get_message_reader(self, options: typing.Optional[EmailQueryOptions]) -> typing.Optional[EmailMessageReader]: ...
    def save_message_async(self, message: typing.Optional[EmailMessage]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def try_move_async(self, new_parent_folder: typing.Optional[EmailFolder]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @typing.overload
    def try_move_async(self, new_parent_folder: typing.Optional[EmailFolder], new_folder_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_save_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class EmailIrmInfo(winsdk.system.Object):
    can_remove_irm_on_response: winsdk.system.Boolean
    can_print_data: winsdk.system.Boolean
    can_modify_recipients_on_response: winsdk.system.Boolean
    can_forward: winsdk.system.Boolean
    can_extract_data: winsdk.system.Boolean
    can_reply: winsdk.system.Boolean
    can_edit: winsdk.system.Boolean
    template: typing.Optional[EmailIrmTemplate]
    is_programatic_access_allowed: winsdk.system.Boolean
    is_irm_originator: winsdk.system.Boolean
    expiration_date: datetime.datetime
    can_reply_all: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailIrmInfo: ...
    @typing.overload
    def __new__(cls: typing.Type[EmailIrmInfo], expiration: datetime.datetime, irm_template: typing.Optional[EmailIrmTemplate]) -> EmailIrmInfo:...
    @typing.overload
    def __new__(cls: typing.Type[EmailIrmInfo]) -> EmailIrmInfo:...

class EmailIrmTemplate(winsdk.system.Object):
    name: str
    id: str
    description: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailIrmTemplate: ...
    @typing.overload
    def __new__(cls: typing.Type[EmailIrmTemplate], id: str, name: str, description: str) -> EmailIrmTemplate:...
    @typing.overload
    def __new__(cls: typing.Type[EmailIrmTemplate]) -> EmailIrmTemplate:...

class EmailItemCounts(winsdk.system.Object):
    flagged: winsdk.system.UInt32
    important: winsdk.system.UInt32
    total: winsdk.system.UInt32
    unread: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailItemCounts: ...

class EmailMailbox(winsdk.system.Object):
    other_app_write_access: EmailMailboxOtherAppWriteAccess
    mail_address: str
    other_app_read_access: EmailMailboxOtherAppReadAccess
    display_name: str
    id: str
    is_data_encrypted_under_lock: winsdk.system.Boolean
    is_owned_by_current_app: winsdk.system.Boolean
    mail_address_aliases: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    capabilities: typing.Optional[EmailMailboxCapabilities]
    change_tracker: typing.Optional[EmailMailboxChangeTracker]
    policies: typing.Optional[EmailMailboxPolicies]
    source_display_name: str
    sync_manager: typing.Optional[EmailMailboxSyncManager]
    user_data_account_id: str
    linked_mailbox_id: str
    network_account_id: str
    network_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailbox: ...
    def change_message_flag_state_async(self, message_id: str, flag_state: EmailFlagState) -> winsdk.windows.foundation.IAsyncAction: ...
    def create_response_message_async(self, message_id: str, response_type: EmailMessageResponseKind, subject: str, response_header_type: EmailMessageBodyKind, response_header: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMessage]: ...
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete_message_async(self, message_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def download_attachment_async(self, attachment_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def download_message_async(self, message_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_change_tracker(self, identity: str) -> typing.Optional[EmailMailboxChangeTracker]: ...
    def get_conversation_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailConversation]: ...
    @typing.overload
    def get_conversation_reader(self) -> typing.Optional[EmailConversationReader]: ...
    @typing.overload
    def get_conversation_reader(self, options: typing.Optional[EmailQueryOptions]) -> typing.Optional[EmailConversationReader]: ...
    def get_folder_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailFolder]: ...
    def get_message_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMessage]: ...
    @typing.overload
    def get_message_reader(self) -> typing.Optional[EmailMessageReader]: ...
    @typing.overload
    def get_message_reader(self, options: typing.Optional[EmailQueryOptions]) -> typing.Optional[EmailMessageReader]: ...
    def get_special_folder_async(self, folder_type: EmailSpecialFolderKind) -> winsdk.windows.foundation.IAsyncOperation[EmailFolder]: ...
    def mark_folder_as_seen_async(self, folder_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def mark_folder_sync_enabled_async(self, folder_id: str, is_sync_enabled: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncAction: ...
    def mark_message_as_seen_async(self, message_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def mark_message_read_async(self, message_id: str, is_read: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncAction: ...
    def register_sync_manager_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def resolve_recipients_async(self, recipients: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EmailRecipientResolutionResult]]: ...
    def save_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def save_draft_async(self, message: typing.Optional[EmailMessage]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def send_message_async(self, message: typing.Optional[EmailMessage]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def send_message_async(self, message: typing.Optional[EmailMessage], smart_send: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_create_folder_async(self, parent_folder_id: str, name: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMailboxCreateFolderResult]: ...
    def try_delete_folder_async(self, folder_id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMailboxDeleteFolderStatus]: ...
    def try_empty_folder_async(self, folder_id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMailboxEmptyFolderStatus]: ...
    def try_forward_meeting_async(self, meeting: typing.Optional[EmailMessage], recipients: typing.Iterable[EmailRecipient], subject: str, forward_header_type: EmailMessageBodyKind, forward_header: str, comment: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_get_auto_reply_settings_async(self, requested_format: EmailMailboxAutoReplyMessageResponseKind) -> winsdk.windows.foundation.IAsyncOperation[EmailMailboxAutoReplySettings]: ...
    @typing.overload
    def try_move_folder_async(self, folder_id: str, new_parent_folder_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @typing.overload
    def try_move_folder_async(self, folder_id: str, new_parent_folder_id: str, new_folder_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_move_message_async(self, message_id: str, new_parent_folder_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_propose_new_time_for_meeting_async(self, meeting: typing.Optional[EmailMessage], new_start_time: datetime.datetime, new_duration: datetime.timedelta, subject: str, comment: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_set_auto_reply_settings_async(self, auto_reply_settings: typing.Optional[EmailMailboxAutoReplySettings]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_update_meeting_response_async(self, meeting: typing.Optional[EmailMessage], response: EmailMeetingResponseType, subject: str, comment: str, send_update: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def validate_certificates_async(self, certificates: typing.Iterable[winsdk.windows.security.cryptography.certificates.Certificate]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EmailCertificateValidationStatus]]: ...
    def add_mailbox_changed(self, p_handler: winsdk.windows.foundation.TypedEventHandler[EmailMailbox, EmailMailboxChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_mailbox_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class EmailMailboxAction(winsdk.system.Object):
    change_number: winsdk.system.UInt64
    kind: EmailMailboxActionKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxAction: ...

class EmailMailboxAutoReply(winsdk.system.Object):
    response: str
    is_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxAutoReply: ...

class EmailMailboxAutoReplySettings(winsdk.system.Object):
    start_time: typing.Optional[typing.Optional[datetime.datetime]]
    response_kind: EmailMailboxAutoReplyMessageResponseKind
    is_enabled: winsdk.system.Boolean
    end_time: typing.Optional[typing.Optional[datetime.datetime]]
    internal_reply: typing.Optional[EmailMailboxAutoReply]
    known_external_reply: typing.Optional[EmailMailboxAutoReply]
    unknown_external_reply: typing.Optional[EmailMailboxAutoReply]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxAutoReplySettings: ...
    def __new__(cls: typing.Type[EmailMailboxAutoReplySettings]) -> EmailMailboxAutoReplySettings:...

class EmailMailboxCapabilities(winsdk.system.Object):
    can_smart_send: winsdk.system.Boolean
    can_update_meeting_responses: winsdk.system.Boolean
    can_server_search_mailbox: winsdk.system.Boolean
    can_server_search_folders: winsdk.system.Boolean
    can_forward_meetings: winsdk.system.Boolean
    can_propose_new_time_for_meetings: winsdk.system.Boolean
    can_get_and_set_internal_auto_replies: winsdk.system.Boolean
    can_get_and_set_external_auto_replies: winsdk.system.Boolean
    can_validate_certificates: winsdk.system.Boolean
    can_resolve_recipients: winsdk.system.Boolean
    can_move_folder: winsdk.system.Boolean
    can_empty_folder: winsdk.system.Boolean
    can_delete_folder: winsdk.system.Boolean
    can_create_folder: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxCapabilities: ...

class EmailMailboxChange(winsdk.system.Object):
    change_type: EmailMailboxChangeType
    folder: typing.Optional[EmailFolder]
    mailbox_actions: typing.Optional[winsdk.windows.foundation.collections.IVector[EmailMailboxAction]]
    message: typing.Optional[EmailMessage]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxChange: ...

class EmailMailboxChangeReader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxChangeReader: ...
    def accept_changes(self) -> None: ...
    def accept_changes_through(self, last_change_to_acknowledge: typing.Optional[EmailMailboxChange]) -> None: ...
    def read_batch_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EmailMailboxChange]]: ...

class EmailMailboxChangeTracker(winsdk.system.Object):
    is_tracking: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxChangeTracker: ...
    def enable(self) -> None: ...
    def get_change_reader(self) -> typing.Optional[EmailMailboxChangeReader]: ...
    def reset(self) -> None: ...

class EmailMailboxChangedDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxChangedDeferral: ...
    def complete(self) -> None: ...

class EmailMailboxChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxChangedEventArgs: ...
    def get_deferral(self) -> typing.Optional[EmailMailboxChangedDeferral]: ...

class EmailMailboxCreateFolderResult(winsdk.system.Object):
    folder: typing.Optional[EmailFolder]
    status: EmailMailboxCreateFolderStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxCreateFolderResult: ...

class EmailMailboxPolicies(winsdk.system.Object):
    required_smime_signing_algorithm: typing.Optional[typing.Optional[EmailMailboxSmimeSigningAlgorithm]]
    required_smime_encryption_algorithm: typing.Optional[typing.Optional[EmailMailboxSmimeEncryptionAlgorithm]]
    allowed_smime_encryption_algorithm_negotiation: EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation
    allow_smime_soft_certificates: winsdk.system.Boolean
    must_sign_smime_messages: winsdk.system.Boolean
    must_encrypt_smime_messages: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxPolicies: ...

class EmailMailboxSyncManager(winsdk.system.Object):
    status: EmailMailboxSyncStatus
    last_successful_sync_time: datetime.datetime
    last_attempted_sync_time: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMailboxSyncManager: ...
    def sync_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def add_sync_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[EmailMailboxSyncManager, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sync_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class EmailManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailManager: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[EmailManagerForUser]: ...
    @staticmethod
    def request_store_async(access_type: EmailStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[EmailStore]: ...
    @staticmethod
    def show_compose_new_email_async(message: typing.Optional[EmailMessage]) -> winsdk.windows.foundation.IAsyncAction: ...

class EmailManagerForUser(winsdk.system.Object):
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailManagerForUser: ...
    def request_store_async(self, access_type: EmailStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[EmailStore]: ...
    def show_compose_new_email_async(self, message: typing.Optional[EmailMessage]) -> winsdk.windows.foundation.IAsyncAction: ...

class EmailMeetingInfo(winsdk.system.Object):
    location: str
    is_response_requested: winsdk.system.Boolean
    is_all_day: winsdk.system.Boolean
    allow_new_time_proposal: winsdk.system.Boolean
    duration: datetime.timedelta
    appointment_roaming_id: str
    appointment_original_start_time: typing.Optional[typing.Optional[datetime.datetime]]
    proposed_duration: typing.Optional[typing.Optional[datetime.timedelta]]
    remote_change_number: winsdk.system.UInt64
    start_time: datetime.datetime
    recurrence_start_time: typing.Optional[typing.Optional[datetime.datetime]]
    recurrence: typing.Optional[winsdk.windows.applicationmodel.appointments.AppointmentRecurrence]
    proposed_start_time: typing.Optional[typing.Optional[datetime.datetime]]
    is_reported_out_of_date_by_server: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMeetingInfo: ...
    def __new__(cls: typing.Type[EmailMeetingInfo]) -> EmailMeetingInfo:...

class EmailMessage(winsdk.system.Object):
    subject: str
    body: str
    bcc: typing.Optional[winsdk.windows.foundation.collections.IVector[EmailRecipient]]
    c_c: typing.Optional[winsdk.windows.foundation.collections.IVector[EmailRecipient]]
    attachments: typing.Optional[winsdk.windows.foundation.collections.IVector[EmailAttachment]]
    to: typing.Optional[winsdk.windows.foundation.collections.IVector[EmailRecipient]]
    allow_internet_images: winsdk.system.Boolean
    flag_state: EmailFlagState
    estimated_download_size_in_bytes: winsdk.system.UInt32
    download_state: EmailMessageDownloadState
    importance: EmailImportance
    irm_info: typing.Optional[EmailIrmInfo]
    original_code_page: winsdk.system.Int32
    sent_time: typing.Optional[typing.Optional[datetime.datetime]]
    sender: typing.Optional[EmailRecipient]
    remote_id: str
    preview: str
    message_class: str
    meeting_info: typing.Optional[EmailMeetingInfo]
    last_response_kind: EmailMessageResponseKind
    is_seen: winsdk.system.Boolean
    is_read: winsdk.system.Boolean
    is_server_search_message: winsdk.system.Boolean
    is_smart_sendable: winsdk.system.Boolean
    mailbox_id: str
    change_number: winsdk.system.UInt64
    conversation_id: str
    normalized_subject: str
    folder_id: str
    has_partial_bodies: winsdk.system.Boolean
    id: str
    in_response_to_message_id: str
    is_draft_message: winsdk.system.Boolean
    smime_kind: EmailMessageSmimeKind
    smime_data: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    sent_representing: typing.Optional[EmailRecipient]
    reply_to: typing.Optional[winsdk.windows.foundation.collections.IVector[EmailRecipient]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMessage: ...
    def __new__(cls: typing.Type[EmailMessage]) -> EmailMessage:...
    def get_body_stream(self, type: EmailMessageBodyKind) -> typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]: ...
    def set_body_stream(self, type: EmailMessageBodyKind, stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> None: ...

class EmailMessageBatch(winsdk.system.Object):
    messages: typing.Optional[winsdk.windows.foundation.collections.IVectorView[EmailMessage]]
    status: EmailBatchStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMessageBatch: ...

class EmailMessageReader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailMessageReader: ...
    def read_batch_async(self) -> winsdk.windows.foundation.IAsyncOperation[EmailMessageBatch]: ...

class EmailQueryOptions(winsdk.system.Object):
    sort_property: EmailQuerySortProperty
    sort_direction: EmailQuerySortDirection
    kind: EmailQueryKind
    folder_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    text_search: typing.Optional[EmailQueryTextSearch]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailQueryOptions: ...
    @typing.overload
    def __new__(cls: typing.Type[EmailQueryOptions], text: str) -> EmailQueryOptions:...
    @typing.overload
    def __new__(cls: typing.Type[EmailQueryOptions], text: str, fields: EmailQuerySearchFields) -> EmailQueryOptions:...
    @typing.overload
    def __new__(cls: typing.Type[EmailQueryOptions]) -> EmailQueryOptions:...

class EmailQueryTextSearch(winsdk.system.Object):
    text: str
    search_scope: EmailQuerySearchScope
    fields: EmailQuerySearchFields
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailQueryTextSearch: ...

class EmailRecipient(winsdk.system.Object):
    name: str
    address: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailRecipient: ...
    @typing.overload
    def __new__(cls: typing.Type[EmailRecipient], address: str) -> EmailRecipient:...
    @typing.overload
    def __new__(cls: typing.Type[EmailRecipient], address: str, name: str) -> EmailRecipient:...
    @typing.overload
    def __new__(cls: typing.Type[EmailRecipient]) -> EmailRecipient:...

class EmailRecipientResolutionResult(winsdk.system.Object):
    status: EmailRecipientResolutionStatus
    public_keys: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.Certificate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailRecipientResolutionResult: ...
    def __new__(cls: typing.Type[EmailRecipientResolutionResult]) -> EmailRecipientResolutionResult:...
    def set_public_keys(self, value: typing.Iterable[winsdk.windows.security.cryptography.certificates.Certificate]) -> None: ...

class EmailStore(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailStore: ...
    @typing.overload
    def create_mailbox_async(self, account_name: str, account_address: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMailbox]: ...
    @typing.overload
    def create_mailbox_async(self, account_name: str, account_address: str, user_data_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMailbox]: ...
    def find_mailboxes_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EmailMailbox]]: ...
    def get_conversation_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailConversation]: ...
    @typing.overload
    def get_conversation_reader(self) -> typing.Optional[EmailConversationReader]: ...
    @typing.overload
    def get_conversation_reader(self, options: typing.Optional[EmailQueryOptions]) -> typing.Optional[EmailConversationReader]: ...
    def get_folder_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailFolder]: ...
    def get_mailbox_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMailbox]: ...
    def get_message_async(self, id: str) -> winsdk.windows.foundation.IAsyncOperation[EmailMessage]: ...
    @typing.overload
    def get_message_reader(self) -> typing.Optional[EmailMessageReader]: ...
    @typing.overload
    def get_message_reader(self, options: typing.Optional[EmailQueryOptions]) -> typing.Optional[EmailMessageReader]: ...

class EmailStoreNotificationTriggerDetails(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EmailStoreNotificationTriggerDetails: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.printing
import winsdk.windows.storage.streams

class PrintOptionStates(enum.IntFlag):
    NONE = 0
    ENABLED = 0x1
    CONSTRAINED = 0x2

class PrintOptionType(enum.IntEnum):
    UNKNOWN = 0
    NUMBER = 1
    TEXT = 2
    ITEM_LIST = 3
    TOGGLE = 4

Self = typing.TypeVar('Self')

class PrintBindingOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintBindingOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintBorderingOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintBorderingOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintCollationOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintCollationOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintColorModeOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintColorModeOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintCopiesOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    max_value: winsdk.system.UInt32
    min_value: winsdk.system.UInt32
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintCopiesOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintCustomItemDetails(winsdk.system.Object):
    item_display_name: str
    item_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintCustomItemDetails: ...

class PrintCustomItemListOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    display_name: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintCustomItemListOptionDetails: ...
    @typing.overload
    def add_item(self, item_id: str, display_name: str) -> None: ...
    @typing.overload
    def add_item(self, item_id: str, display_name: str, description: str, icon: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]) -> None: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintCustomTextOptionDetails(winsdk.system.Object):
    display_name: str
    max_characters: winsdk.system.UInt32
    warning_text: str
    description: str
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintCustomTextOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintCustomToggleOptionDetails(winsdk.system.Object):
    display_name: str
    warning_text: str
    description: str
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintCustomToggleOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintDuplexOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintDuplexOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintHolePunchOptionDetails(winsdk.system.Object):
    warning_text: str
    description: str
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintHolePunchOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintMediaSizeOptionDetails(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    warning_text: str
    description: str
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintMediaSizeOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintMediaTypeOptionDetails(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    warning_text: str
    description: str
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintMediaTypeOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintOrientationOptionDetails(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    warning_text: str
    description: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintOrientationOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintPageRangeOptionDetails(winsdk.system.Object):
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    warning_text: str
    description: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintPageRangeOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintQualityOptionDetails(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    warning_text: str
    description: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintQualityOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintStapleOptionDetails(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    state: PrintOptionStates
    error_text: str
    option_id: str
    option_type: PrintOptionType
    value: typing.Optional[winsdk.system.Object]
    warning_text: str
    description: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintStapleOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class PrintTaskOptionChangedEventArgs(winsdk.system.Object):
    option_id: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskOptionChangedEventArgs: ...

class PrintTaskOptionDetails(winsdk.system.Object):
    displayed_options: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    options: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, IPrintOptionDetails]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskOptionDetails: ...
    def create_item_list_option(self, option_id: str, display_name: str) -> typing.Optional[PrintCustomItemListOptionDetails]: ...
    def create_text_option(self, option_id: str, display_name: str) -> typing.Optional[PrintCustomTextOptionDetails]: ...
    def create_toggle_option(self, option_id: str, display_name: str) -> typing.Optional[PrintCustomToggleOptionDetails]: ...
    @staticmethod
    def get_from_print_task_options(print_task_options: typing.Optional[winsdk.windows.graphics.printing.PrintTaskOptions]) -> typing.Optional[PrintTaskOptionDetails]: ...
    def get_page_description(self, job_page_number: winsdk.system.UInt32) -> winsdk.windows.graphics.printing.PrintPageDescription: ...
    def add_begin_validation(self, event_handler: winsdk.windows.foundation.TypedEventHandler[PrintTaskOptionDetails, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_begin_validation(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_option_changed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[PrintTaskOptionDetails, PrintTaskOptionChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_option_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IPrintCustomOptionDetails(winsdk.system.Object):
    display_name: str
    error_text: str
    option_id: str
    option_type: PrintOptionType
    state: PrintOptionStates
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPrintCustomOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class IPrintItemListOptionDetails(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]]
    error_text: str
    option_id: str
    option_type: PrintOptionType
    state: PrintOptionStates
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPrintItemListOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class IPrintNumberOptionDetails(winsdk.system.Object):
    max_value: winsdk.system.UInt32
    min_value: winsdk.system.UInt32
    error_text: str
    option_id: str
    option_type: PrintOptionType
    state: PrintOptionStates
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPrintNumberOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class IPrintOptionDetails(winsdk.system.Object):
    error_text: str
    option_id: str
    option_type: PrintOptionType
    state: PrintOptionStates
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPrintOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class IPrintTextOptionDetails(winsdk.system.Object):
    max_characters: winsdk.system.UInt32
    error_text: str
    option_id: str
    option_type: PrintOptionType
    state: PrintOptionStates
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPrintTextOptionDetails: ...
    def try_set_value(self, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Storage.AccessCache")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class AccessCacheOptions(enum.IntFlag):
    NONE = 0
    DISALLOW_USER_INPUT = 0x1
    FAST_LOCATIONS_ONLY = 0x2
    USE_READ_ONLY_CACHED_COPY = 0x4
    SUPPRESS_ACCESS_TIME_UPDATE = 0x8

class RecentStorageItemVisibility(enum.IntEnum):
    APP_ONLY = 0
    APP_AND_SYSTEM = 1

_ns_module._register_AccessCacheOptions(AccessCacheOptions)
_ns_module._register_RecentStorageItemVisibility(RecentStorageItemVisibility)

AccessListEntry = _ns_module.AccessListEntry
AccessListEntryView = _ns_module.AccessListEntryView
ItemRemovedEventArgs = _ns_module.ItemRemovedEventArgs
StorageApplicationPermissions = _ns_module.StorageApplicationPermissions
StorageItemAccessList = _ns_module.StorageItemAccessList
StorageItemMostRecentlyUsedList = _ns_module.StorageItemMostRecentlyUsedList
IStorageItemAccessList = _ns_module.IStorageItemAccessList



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class WindowsUpdateAdministratorOptions(enum.IntFlag):
    NONE = 0
    REQUIRE_ADMINISTRATOR_APPROVAL_FOR_SCANS = 0x1
    REQUIRE_ADMINISTRATOR_APPROVAL_FOR_UPDATES = 0x2
    REQUIRE_ADMINISTRATOR_APPROVAL_FOR_ACTIONS = 0x4

class WindowsUpdateAdministratorStatus(enum.IntEnum):
    SUCCEEDED = 0
    NO_ADMINISTRATOR_REGISTERED = 1
    OTHER_ADMINISTRATOR_IS_REGISTERED = 2

class WindowsUpdateAttentionRequiredReason(enum.IntEnum):
    NONE = 0
    SEEKER_UPDATE = 1
    READY_TO_REBOOT = 2
    NEED_NON_METERED_NETWORK = 3
    NEED_USER_AGREEMENT_FOR_METERED_NETWORK = 4
    NEED_NETWORK = 5
    NEED_MORE_SPACE = 6
    BATTERY_SAVER_ENABLED = 7
    NEED_USER_INTERACTION = 8
    NEED_USER_AGREEMENT_FOR_POLICY = 9
    COMPATIBILITY_ERROR = 10
    NEED_USER_INTERACTION_FOR_EULA = 11
    NEED_USER_INTERACTION_FOR_CTA = 12
    REGULATED = 13
    EXTERNAL_REBOOT = 14
    OTHER_UPDATE = 15
    BLOCKED_BY_PROVIDER = 16
    BLOCKED_BY_POST_REBOOT_FAILURE = 17
    USER_ENGAGED = 18
    BLOCKED_BY_BATTERY = 19
    EXCLUSIVITY = 20
    BLOCKED_BY_SERIALIZATION = 21
    CONFLICT_CLASS = 22
    BLOCKED_BY_ADMIN_APPROVAL = 23
    BLOCKED_BY_TOO_MANY_ATTEMPTS = 24
    BLOCKED_BY_FAILURE = 25
    DEMOTION = 26
    BLOCKED_BY_ACTIVE_HOURS = 27
    SCHEDULED_FOR_MAINTENANCE = 28
    POLICY_SCHEDULED_INSTALL_TIME = 29
    BLOCKED_BY_OOBE = 30
    DEFERRED_DURING_OOBE = 31
    DEFERRED_FOR_SUSTAINABLE_TIME = 32

Self = typing.TypeVar('Self')

class PreviewBuildsManager(winsdk.system.Object):
    are_preview_builds_allowed: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PreviewBuildsManager: ...
    def get_current_state(self) -> typing.Optional[PreviewBuildsState]: ...
    @staticmethod
    def get_default() -> typing.Optional[PreviewBuildsManager]: ...
    @staticmethod
    def is_supported() -> winsdk.system.Boolean: ...
    def sync_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class PreviewBuildsState(winsdk.system.Object):
    properties: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PreviewBuildsState: ...

class WindowsUpdate(winsdk.system.Object):
    action_progress: typing.Optional[WindowsUpdateActionProgress]
    action_result: typing.Optional[WindowsUpdateActionResult]
    attention_required_info: typing.Optional[WindowsUpdateAttentionRequiredInfo]
    current_action: str
    deadline: typing.Optional[typing.Optional[datetime.datetime]]
    description: str
    eula_text: str
    is_critical: winsdk.system.Boolean
    is_driver: winsdk.system.Boolean
    is_eula_accepted: winsdk.system.Boolean
    is_feature_update: winsdk.system.Boolean
    is_for_o_s: winsdk.system.Boolean
    is_mandatory: winsdk.system.Boolean
    is_minor_impact: winsdk.system.Boolean
    is_security: winsdk.system.Boolean
    is_seeker: winsdk.system.Boolean
    is_urgent: winsdk.system.Boolean
    more_info_url: typing.Optional[winsdk.windows.foundation.Uri]
    provider_id: str
    support_url: typing.Optional[winsdk.windows.foundation.Uri]
    title: str
    update_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdate: ...
    def accept_eula(self) -> None: ...
    def get_property_value(self, property_name: str) -> typing.Optional[winsdk.system.Object]: ...

class WindowsUpdateActionCompletedEventArgs(winsdk.system.Object):
    action: str
    extended_error: winsdk.windows.foundation.HResult
    succeeded: winsdk.system.Boolean
    update: typing.Optional[WindowsUpdate]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateActionCompletedEventArgs: ...

class WindowsUpdateActionProgress(winsdk.system.Object):
    action: str
    progress: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateActionProgress: ...

class WindowsUpdateActionResult(winsdk.system.Object):
    action: str
    extended_error: winsdk.windows.foundation.HResult
    succeeded: winsdk.system.Boolean
    timestamp: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateActionResult: ...

class WindowsUpdateAdministrator(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateAdministrator: ...
    def approve_windows_update(self, update_id: str, approval_data: typing.Optional[WindowsUpdateApprovalData]) -> None: ...
    def approve_windows_update_action(self, update_id: str, action: str) -> None: ...
    @staticmethod
    def cancel_restart_request(request_restart_token: str) -> None: ...
    @staticmethod
    def get_registered_administrator(organization_name: str) -> typing.Optional[WindowsUpdateGetAdministratorResult]: ...
    @staticmethod
    def get_registered_administrator_name() -> str: ...
    def get_updates(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[WindowsUpdate]]: ...
    @staticmethod
    def register_for_administration(organization_name: str, options: WindowsUpdateAdministratorOptions) -> WindowsUpdateAdministratorStatus: ...
    @staticmethod
    def request_restart(restart_options: typing.Optional[WindowsUpdateRestartRequestOptions]) -> str: ...
    def revoke_windows_update_action_approval(self, update_id: str, action: str) -> None: ...
    def revoke_windows_update_approval(self, update_id: str) -> None: ...
    def start_administrator_scan(self) -> None: ...
    @staticmethod
    def unregister_for_administration(organization_name: str) -> WindowsUpdateAdministratorStatus: ...

class WindowsUpdateApprovalData(winsdk.system.Object):
    seeker: typing.Optional[typing.Optional[winsdk.system.Boolean]]
    opt_out_of_auto_reboot: typing.Optional[typing.Optional[winsdk.system.Boolean]]
    compliance_grace_period_in_days: typing.Optional[typing.Optional[winsdk.system.Int32]]
    compliance_deadline_in_days: typing.Optional[typing.Optional[winsdk.system.Int32]]
    allow_download_on_metered: typing.Optional[typing.Optional[winsdk.system.Boolean]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateApprovalData: ...
    def __new__(cls: typing.Type[WindowsUpdateApprovalData]) -> WindowsUpdateApprovalData:...

class WindowsUpdateAttentionRequiredInfo(winsdk.system.Object):
    reason: WindowsUpdateAttentionRequiredReason
    timestamp: typing.Optional[typing.Optional[datetime.datetime]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateAttentionRequiredInfo: ...

class WindowsUpdateAttentionRequiredReasonChangedEventArgs(winsdk.system.Object):
    reason: WindowsUpdateAttentionRequiredReason
    update: typing.Optional[WindowsUpdate]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateAttentionRequiredReasonChangedEventArgs: ...

class WindowsUpdateGetAdministratorResult(winsdk.system.Object):
    administrator: typing.Optional[WindowsUpdateAdministrator]
    status: WindowsUpdateAdministratorStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateGetAdministratorResult: ...

class WindowsUpdateItem(winsdk.system.Object):
    category: str
    description: str
    more_info_url: typing.Optional[winsdk.windows.foundation.Uri]
    operation: str
    provider_id: str
    timestamp: datetime.datetime
    title: str
    update_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateItem: ...

class WindowsUpdateManager(winsdk.system.Object):
    is_scanning: winsdk.system.Boolean
    is_working: winsdk.system.Boolean
    last_successful_scan_timestamp: typing.Optional[typing.Optional[datetime.datetime]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateManager: ...
    def __new__(cls: typing.Type[WindowsUpdateManager], client_id: str) -> WindowsUpdateManager:...
    def get_applicable_updates(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[WindowsUpdate]]: ...
    def get_most_recent_completed_updates(self, count: winsdk.system.Int32) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[WindowsUpdateItem]]: ...
    def get_most_recent_completed_updates_async(self, count: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[WindowsUpdateItem]]: ...
    def start_scan(self, user_initiated: winsdk.system.Boolean) -> None: ...
    def add_action_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[WindowsUpdateManager, WindowsUpdateActionCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_action_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_attention_required_reason_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[WindowsUpdateManager, WindowsUpdateAttentionRequiredReasonChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_attention_required_reason_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_progress_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[WindowsUpdateManager, WindowsUpdateProgressChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_progress_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_scan_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[WindowsUpdateManager, WindowsUpdateScanCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_scan_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_scanning_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[WindowsUpdateManager, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_scanning_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_working_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[WindowsUpdateManager, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_working_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WindowsUpdateProgressChangedEventArgs(winsdk.system.Object):
    action_progress: typing.Optional[WindowsUpdateActionProgress]
    update: typing.Optional[WindowsUpdate]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateProgressChangedEventArgs: ...

class WindowsUpdateRestartRequestOptions(winsdk.system.Object):
    title: str
    organization_name: str
    opt_out_of_auto_reboot: winsdk.system.Boolean
    more_info_url: typing.Optional[winsdk.windows.foundation.Uri]
    description: str
    compliance_grace_period_in_days: winsdk.system.Int32
    compliance_deadline_in_days: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateRestartRequestOptions: ...
    @typing.overload
    def __new__(cls: typing.Type[WindowsUpdateRestartRequestOptions], title: str, description: str, more_info_url: typing.Optional[winsdk.windows.foundation.Uri], compliance_deadline_in_days: winsdk.system.Int32, compliance_grace_period_in_days: winsdk.system.Int32) -> WindowsUpdateRestartRequestOptions:...
    @typing.overload
    def __new__(cls: typing.Type[WindowsUpdateRestartRequestOptions]) -> WindowsUpdateRestartRequestOptions:...

class WindowsUpdateScanCompletedEventArgs(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    provider_id: str
    succeeded: winsdk.system.Boolean
    updates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[WindowsUpdate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowsUpdateScanCompletedEventArgs: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Gpio.Provider")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class ProviderGpioPinDriveMode(enum.IntEnum):
    INPUT = 0
    OUTPUT = 1
    INPUT_PULL_UP = 2
    INPUT_PULL_DOWN = 3
    OUTPUT_OPEN_DRAIN = 4
    OUTPUT_OPEN_DRAIN_PULL_UP = 5
    OUTPUT_OPEN_SOURCE = 6
    OUTPUT_OPEN_SOURCE_PULL_DOWN = 7

class ProviderGpioPinEdge(enum.IntEnum):
    FALLING_EDGE = 0
    RISING_EDGE = 1

class ProviderGpioPinValue(enum.IntEnum):
    LOW = 0
    HIGH = 1

class ProviderGpioSharingMode(enum.IntEnum):
    EXCLUSIVE = 0
    SHARED_READ_ONLY = 1

_ns_module._register_ProviderGpioPinDriveMode(ProviderGpioPinDriveMode)
_ns_module._register_ProviderGpioPinEdge(ProviderGpioPinEdge)
_ns_module._register_ProviderGpioPinValue(ProviderGpioPinValue)
_ns_module._register_ProviderGpioSharingMode(ProviderGpioSharingMode)

GpioPinProviderValueChangedEventArgs = _ns_module.GpioPinProviderValueChangedEventArgs
IGpioControllerProvider = _ns_module.IGpioControllerProvider
IGpioPinProvider = _ns_module.IGpioPinProvider
IGpioProvider = _ns_module.IGpioProvider



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.UserDataTasks.DataProvider")

try:
    import winsdk.windows.applicationmodel.userdatatasks
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass


UserDataTaskDataProviderConnection = _ns_module.UserDataTaskDataProviderConnection
UserDataTaskDataProviderTriggerDetails = _ns_module.UserDataTaskDataProviderTriggerDetails
UserDataTaskListCompleteTaskRequest = _ns_module.UserDataTaskListCompleteTaskRequest
UserDataTaskListCompleteTaskRequestEventArgs = _ns_module.UserDataTaskListCompleteTaskRequestEventArgs
UserDataTaskListCreateOrUpdateTaskRequest = _ns_module.UserDataTaskListCreateOrUpdateTaskRequest
UserDataTaskListCreateOrUpdateTaskRequestEventArgs = _ns_module.UserDataTaskListCreateOrUpdateTaskRequestEventArgs
UserDataTaskListDeleteTaskRequest = _ns_module.UserDataTaskListDeleteTaskRequest
UserDataTaskListDeleteTaskRequestEventArgs = _ns_module.UserDataTaskListDeleteTaskRequestEventArgs
UserDataTaskListSkipOccurrenceRequest = _ns_module.UserDataTaskListSkipOccurrenceRequest
UserDataTaskListSkipOccurrenceRequestEventArgs = _ns_module.UserDataTaskListSkipOccurrenceRequestEventArgs
UserDataTaskListSyncManagerSyncRequest = _ns_module.UserDataTaskListSyncManagerSyncRequest
UserDataTaskListSyncManagerSyncRequestEventArgs = _ns_module.UserDataTaskListSyncManagerSyncRequestEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class IsolatedWindowsEnvironmentActivator(enum.IntEnum):
    SYSTEM = 0
    USER = 1

class IsolatedWindowsEnvironmentAllowedClipboardFormats(enum.IntFlag):
    NONE = 0
    TEXT = 0x1
    IMAGE = 0x2
    RTF = 0x4

class IsolatedWindowsEnvironmentAvailablePrinters(enum.IntFlag):
    NONE = 0
    LOCAL = 0x1
    NETWORK = 0x2
    SYSTEM_PRINT_TO_PDF = 0x4
    SYSTEM_PRINT_TO_XPS = 0x8

class IsolatedWindowsEnvironmentClipboardCopyPasteDirections(enum.IntFlag):
    NONE = 0
    HOST_TO_ISOLATED_WINDOWS_ENVIRONMENT = 0x1
    ISOLATED_WINDOWS_ENVIRONMENT_TO_HOST = 0x2

class IsolatedWindowsEnvironmentCreateStatus(enum.IntEnum):
    SUCCESS = 0
    FAILURE_BY_POLICY = 1
    UNKNOWN_FAILURE = 2

class IsolatedWindowsEnvironmentCreationPriority(enum.IntEnum):
    LOW = 0
    NORMAL = 1

class IsolatedWindowsEnvironmentHostError(enum.IntEnum):
    ADMIN_POLICY_IS_DISABLED_OR_NOT_PRESENT = 0
    FEATURE_NOT_INSTALLED = 1
    HARDWARE_REQUIREMENTS_NOT_MET = 2
    REBOOT_REQUIRED = 3
    UNKNOWN_ERROR = 4

class IsolatedWindowsEnvironmentLaunchFileStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    ENVIRONMENT_UNAVAILABLE = 2
    FILE_NOT_FOUND = 3
    TIMED_OUT = 4
    ALREADY_SHARED_WITH_CONFLICTING_OPTIONS = 5

class IsolatedWindowsEnvironmentOwnerRegistrationStatus(enum.IntEnum):
    SUCCESS = 0
    INVALID_ARGUMENT = 1
    ACCESS_DENIED = 2
    INSUFFICIENT_MEMORY = 3
    UNKNOWN_FAILURE = 4

class IsolatedWindowsEnvironmentPostMessageStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    ENVIRONMENT_UNAVAILABLE = 2

class IsolatedWindowsEnvironmentProcessState(enum.IntEnum):
    RUNNING = 1
    ABORTED = 2
    COMPLETED = 3

class IsolatedWindowsEnvironmentProgressState(enum.IntEnum):
    QUEUED = 0
    PROCESSING = 1
    COMPLETED = 2
    CREATING = 3
    RETRYING = 4
    STARTING = 5
    FINALIZING = 6

class IsolatedWindowsEnvironmentShareFileStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    ENVIRONMENT_UNAVAILABLE = 2
    ALREADY_SHARED_WITH_CONFLICTING_OPTIONS = 3
    FILE_NOT_FOUND = 4
    ACCESS_DENIED = 5

class IsolatedWindowsEnvironmentShareFolderStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    ENVIRONMENT_UNAVAILABLE = 2
    FOLDER_NOT_FOUND = 3
    ACCESS_DENIED = 4

class IsolatedWindowsEnvironmentSignInProgress(enum.IntEnum):
    CONNECTING = 0
    CONNECTED = 1
    AUTHENTICATING = 2
    SETTING_UP_ACCOUNT = 3
    FINALIZING = 4
    COMPLETED = 5

class IsolatedWindowsEnvironmentStartProcessStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    ENVIRONMENT_UNAVAILABLE = 2
    FILE_NOT_FOUND = 3
    APP_NOT_REGISTERED = 4

Self = typing.TypeVar('Self')

class IsolatedWindowsEnvironmentCreateProgress:
    state: IsolatedWindowsEnvironmentProgressState
    percent_complete: winsdk.system.UInt32
    def __new__(cls: typing.Type[IsolatedWindowsEnvironmentCreateProgress], state: IsolatedWindowsEnvironmentProgressState, percent_complete: winsdk.system.UInt32) -> IsolatedWindowsEnvironmentCreateProgress: ...

class IsolatedWindowsEnvironment(winsdk.system.Object):
    id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironment: ...
    def change_priority(self, priority: IsolatedWindowsEnvironmentCreationPriority) -> None: ...
    @typing.overload
    @staticmethod
    def create_async(options: typing.Optional[IsolatedWindowsEnvironmentOptions]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IsolatedWindowsEnvironmentCreateResult, IsolatedWindowsEnvironmentCreateProgress]: ...
    @typing.overload
    @staticmethod
    def create_async(options: typing.Optional[IsolatedWindowsEnvironmentOptions], telemetry_parameters: typing.Optional[IsolatedWindowsEnvironmentTelemetryParameters]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IsolatedWindowsEnvironmentCreateResult, IsolatedWindowsEnvironmentCreateProgress]: ...
    @staticmethod
    def find_by_owner_id(environment_owner_id: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[IsolatedWindowsEnvironment]]: ...
    @staticmethod
    def get_by_id(environment_id: str) -> typing.Optional[IsolatedWindowsEnvironment]: ...
    def get_user_info(self) -> typing.Optional[IsolatedWindowsEnvironmentUserInfo]: ...
    @typing.overload
    def launch_file_with_u_i_async(self, app_exe_path: str, arguments_template: str, file_path: str) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentLaunchFileResult]: ...
    @typing.overload
    def launch_file_with_u_i_async(self, app_exe_path: str, arguments_template: str, file_path: str, telemetry_parameters: typing.Optional[IsolatedWindowsEnvironmentTelemetryParameters]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentLaunchFileResult]: ...
    @typing.overload
    def post_message_to_receiver_async(self, receiver_id: winsdk.system.Guid, message: typing.Iterable[winsdk.system.Object]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentPostMessageResult]: ...
    @typing.overload
    def post_message_to_receiver_async(self, receiver_id: winsdk.system.Guid, message: typing.Iterable[winsdk.system.Object], telemetry_parameters: typing.Optional[IsolatedWindowsEnvironmentTelemetryParameters]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentPostMessageResult]: ...
    def register_message_receiver(self, receiver_id: winsdk.system.Guid, message_received_callback: typing.Optional[MessageReceivedCallback]) -> None: ...
    @typing.overload
    def share_file_async(self, file_path: str, options: typing.Optional[IsolatedWindowsEnvironmentShareFileRequestOptions]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentShareFileResult]: ...
    @typing.overload
    def share_file_async(self, file_path: str, options: typing.Optional[IsolatedWindowsEnvironmentShareFileRequestOptions], telemetry_parameters: typing.Optional[IsolatedWindowsEnvironmentTelemetryParameters]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentShareFileResult]: ...
    @typing.overload
    def share_folder_async(self, host_folder: str, request_options: typing.Optional[IsolatedWindowsEnvironmentShareFolderRequestOptions]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentShareFolderResult]: ...
    @typing.overload
    def share_folder_async(self, host_folder: str, request_options: typing.Optional[IsolatedWindowsEnvironmentShareFolderRequestOptions], telemetry_parameters: typing.Optional[IsolatedWindowsEnvironmentTelemetryParameters]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentShareFolderResult]: ...
    @typing.overload
    def start_process_silently_async(self, host_exe_path: str, arguments: str, activator: IsolatedWindowsEnvironmentActivator) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentStartProcessResult]: ...
    @typing.overload
    def start_process_silently_async(self, host_exe_path: str, arguments: str, activator: IsolatedWindowsEnvironmentActivator, telemetry_parameters: typing.Optional[IsolatedWindowsEnvironmentTelemetryParameters]) -> winsdk.windows.foundation.IAsyncOperation[IsolatedWindowsEnvironmentStartProcessResult]: ...
    @typing.overload
    def terminate_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def terminate_async(self, telemetry_parameters: typing.Optional[IsolatedWindowsEnvironmentTelemetryParameters]) -> winsdk.windows.foundation.IAsyncAction: ...
    def unregister_message_receiver(self, receiver_id: winsdk.system.Guid) -> None: ...

class IsolatedWindowsEnvironmentCreateResult(winsdk.system.Object):
    environment: typing.Optional[IsolatedWindowsEnvironment]
    extended_error: winsdk.windows.foundation.HResult
    status: IsolatedWindowsEnvironmentCreateStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentCreateResult: ...
    def change_creation_priority(self, priority: IsolatedWindowsEnvironmentCreationPriority) -> None: ...

class IsolatedWindowsEnvironmentFile(winsdk.system.Object):
    host_path: str
    id: winsdk.system.Guid
    guest_path: str
    is_read_only: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentFile: ...
    def close(self) -> None: ...

class IsolatedWindowsEnvironmentHost(winsdk.system.Object):
    host_errors: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[IsolatedWindowsEnvironmentHostError]]]
    is_ready: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentHost: ...

class IsolatedWindowsEnvironmentLaunchFileResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    file: typing.Optional[IsolatedWindowsEnvironmentFile]
    status: IsolatedWindowsEnvironmentLaunchFileStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentLaunchFileResult: ...

class IsolatedWindowsEnvironmentOptions(winsdk.system.Object):
    persist_user_profile: winsdk.system.Boolean
    environment_owner_id: str
    clipboard_copy_paste_directions: IsolatedWindowsEnvironmentClipboardCopyPasteDirections
    available_printers: IsolatedWindowsEnvironmentAvailablePrinters
    allowed_clipboard_formats: IsolatedWindowsEnvironmentAllowedClipboardFormats
    allow_graphics_hardware_acceleration: winsdk.system.Boolean
    allow_camera_and_microphone_access: winsdk.system.Boolean
    shared_folder_name_in_environment: str
    shared_host_folder_path: str
    window_annotation_override: str
    creation_priority: IsolatedWindowsEnvironmentCreationPriority
    allowed_clipboard_formats_to_host: IsolatedWindowsEnvironmentAllowedClipboardFormats
    allowed_clipboard_formats_to_environment: IsolatedWindowsEnvironmentAllowedClipboardFormats
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentOptions: ...
    def __new__(cls: typing.Type[IsolatedWindowsEnvironmentOptions]) -> IsolatedWindowsEnvironmentOptions:...
    def share_host_folder_for_untrusted_items(self, shared_host_folder_path: str, share_folder_name_in_environment: str) -> None: ...

class IsolatedWindowsEnvironmentOwnerRegistration(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentOwnerRegistration: ...
    @staticmethod
    def register(owner_name: str, owner_registration_data: typing.Optional[IsolatedWindowsEnvironmentOwnerRegistrationData]) -> typing.Optional[IsolatedWindowsEnvironmentOwnerRegistrationResult]: ...
    @staticmethod
    def unregister(owner_name: str) -> None: ...

class IsolatedWindowsEnvironmentOwnerRegistrationData(winsdk.system.Object):
    activation_file_extensions: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    processes_runnable_as_system: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    processes_runnable_as_user: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    shareable_folders: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentOwnerRegistrationData: ...
    def __new__(cls: typing.Type[IsolatedWindowsEnvironmentOwnerRegistrationData]) -> IsolatedWindowsEnvironmentOwnerRegistrationData:...

class IsolatedWindowsEnvironmentOwnerRegistrationResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    status: IsolatedWindowsEnvironmentOwnerRegistrationStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentOwnerRegistrationResult: ...

class IsolatedWindowsEnvironmentPostMessageResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    status: IsolatedWindowsEnvironmentPostMessageStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentPostMessageResult: ...

class IsolatedWindowsEnvironmentProcess(winsdk.system.Object):
    exit_code: winsdk.system.UInt32
    state: IsolatedWindowsEnvironmentProcessState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentProcess: ...
    def wait_for_exit(self) -> None: ...
    def wait_for_exit_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def wait_for_exit_with_timeout(self, timeout_milliseconds: winsdk.system.UInt32) -> None: ...

class IsolatedWindowsEnvironmentShareFileRequestOptions(winsdk.system.Object):
    allow_write: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentShareFileRequestOptions: ...
    def __new__(cls: typing.Type[IsolatedWindowsEnvironmentShareFileRequestOptions]) -> IsolatedWindowsEnvironmentShareFileRequestOptions:...

class IsolatedWindowsEnvironmentShareFileResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    file: typing.Optional[IsolatedWindowsEnvironmentFile]
    status: IsolatedWindowsEnvironmentShareFileStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentShareFileResult: ...

class IsolatedWindowsEnvironmentShareFolderRequestOptions(winsdk.system.Object):
    allow_write: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentShareFolderRequestOptions: ...
    def __new__(cls: typing.Type[IsolatedWindowsEnvironmentShareFolderRequestOptions]) -> IsolatedWindowsEnvironmentShareFolderRequestOptions:...

class IsolatedWindowsEnvironmentShareFolderResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    status: IsolatedWindowsEnvironmentShareFolderStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentShareFolderResult: ...

class IsolatedWindowsEnvironmentStartProcessResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    process: typing.Optional[IsolatedWindowsEnvironmentProcess]
    status: IsolatedWindowsEnvironmentStartProcessStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentStartProcessResult: ...

class IsolatedWindowsEnvironmentTelemetryParameters(winsdk.system.Object):
    correlation_id: winsdk.system.Guid
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentTelemetryParameters: ...
    def __new__(cls: typing.Type[IsolatedWindowsEnvironmentTelemetryParameters]) -> IsolatedWindowsEnvironmentTelemetryParameters:...

class IsolatedWindowsEnvironmentUserInfo(winsdk.system.Object):
    environment_user_name: str
    environment_user_sid: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsEnvironmentUserInfo: ...
    def try_wait_for_sign_in_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_wait_for_sign_in_with_progress_async(self) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.Boolean, IsolatedWindowsEnvironmentSignInProgress]: ...

class IsolatedWindowsHostMessenger(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsolatedWindowsHostMessenger: ...
    @staticmethod
    def get_file_id(file_path: str) -> winsdk.system.Guid: ...
    @staticmethod
    def post_message_to_receiver(receiver_id: winsdk.system.Guid, message: winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]) -> None: ...
    @staticmethod
    def register_host_message_receiver(receiver_id: winsdk.system.Guid, host_message_received_callback: typing.Optional[HostMessageReceivedCallback]) -> None: ...
    @staticmethod
    def unregister_host_message_receiver(receiver_id: winsdk.system.Guid) -> None: ...

HostMessageReceivedCallback = typing.Callable[[winsdk.system.Guid, winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]], None]

MessageReceivedCallback = typing.Callable[[winsdk.system.Guid, winsdk.windows.foundation.collections.IVectorView[winsdk.system.Object]], None]

